@@ -1,9 +1,9 @@
 /*****************************************************************************
- * RRDtool 1.2.28  Copyright by Tobi Oetiker, 1997-2008
+ * RRDtool 1.2.30  Copyright by Tobi Oetiker, 1997-2009
  *****************************************************************************
  * rrd_fetch.c  read date from an rrd to use for further processing
  *****************************************************************************
- * $Id: rrd_fetch.c 1450 2008-07-23 13:45:41Z oetiker $
+ * $Id: rrd_fetch.c 1735 2009-01-19 14:29:11Z oetiker $
  * $Log$
  * Revision 1.8  2004/05/18 18:53:03  oetiker
  * big spell checking patch -- slif@bellsouth.net
@@ -361,31 +361,36 @@ fprintf(stderr,"partial match, not best\n");
 #endif
 
     /* fill the gap at the start if needs be */
-
-    if (start_offset <= 0)
-	rra_pointer = rrd.rra_ptr[chosen_rra].cur_row+1;
-    else 
-	rra_pointer = rrd.rra_ptr[chosen_rra].cur_row+1+start_offset;
+    if (*start <= rra_end_time && *end >= rra_start_time - *step){
+        
+        if (start_offset <= 0)
+            rra_pointer = rrd.rra_ptr[chosen_rra].cur_row+1;
+        else 
+            rra_pointer = rrd.rra_ptr[chosen_rra].cur_row+1+start_offset;
     
-    if(fseek(in_file,(rra_base 
+        rra_pointer = rra_pointer % (signed) rrd.rra_def[chosen_rra].row_cnt;
+         
+        if(fseek(in_file,(rra_base 
 		   + (rra_pointer
 		      * *ds_cnt
 		      * sizeof(rrd_value_t))),SEEK_SET) != 0){
-	rrd_set_error("seek error in RRA");
-	for (i=0;(unsigned)i<*ds_cnt;i++)
-	      free((*ds_namv)[i]);
-	free(*ds_namv);
-	rrd_free(&rrd);
-	free(*data);
-	*data = NULL;
-	fclose(in_file);
-	return(-1);
+            rrd_set_error("seek error in RRA");
+            for (i=0;(unsigned)i<*ds_cnt;i++)
+                free((*ds_namv)[i]);
+            free(*ds_namv);
+            rrd_free(&rrd);
+            free(*data);
+            *data = NULL;
+            fclose(in_file);
+            return(-1);
 
-    }
+        }
 #ifdef DEBUG
-    fprintf(stderr,"First Seek: rra_base %lu rra_pointer %lu\n",
-	    rra_base, rra_pointer);
+        fprintf(stderr,"First Seek: rra_base %lu rra_pointer %lu\n",
+                rra_base, rra_pointer);
 #endif
+    }
+    
     /* step trough the array */
 
     for (i=start_offset;
