@@ -4,6 +4,7 @@
 #include "rrd_tool.h"
 #include "rrd_rpncalc.h"
 #include "rrd_gfx.h"
+#include <libgen.h>
 
 #define MAX_VNAME_LEN 255
 #define DEF_NAM_FMT "%255[-_A-Za-z0-9]"
@@ -19,6 +20,7 @@
 
 #define FORCE_UNITS 0x100        /* mask for all FORCE_UNITS_* flags */
 #define FORCE_UNITS_SI 0x100     /* force use of SI units in Y axis (no effect in linear graph, SI instead of E in log graph) */
+#define NO_RRDTOOL_TAG 0x200    /* disable the rrdtool tag */
 
 enum tmt_en {TMT_SECOND=0,TMT_MINUTE,TMT_HOUR,TMT_DAY,
 	     TMT_WEEK,TMT_MONTH,TMT_YEAR};
@@ -165,6 +167,11 @@ typedef struct image_desc_t {
     xlab_t         xlab_user;      /* user defined labeling for xaxis */
     char           xlab_form[210]; /* format for the label on the xaxis */
 
+    double         second_axis_scale; /* relative to the first axis (0 to disable) */
+    double         second_axis_shift; /* how much is it shifted vs the first axis */
+    char           second_axis_legend[210]; /* label to put on the seond axis */
+    char           second_axis_format[210]; /* format for the numbers on the scond axis */
+
     double         ygridstep;      /* user defined step for y grid */
     int            ylabfact;       /* every how many y grid shall a label be written ? */
     double         tabwidth;       /* tabwdith */
