@@ -1,9 +1,9 @@
 /*****************************************************************************
- * RRDtool 1.2.28  Copyright by Tobi Oetiker, 1997-2008
+ * RRDtool 1.2.30  Copyright by Tobi Oetiker, 1997-2009
  *****************************************************************************
  * rrd_open.c  Open an RRD File
  *****************************************************************************
- * $Id: rrd_open.c 1450 2008-07-23 13:45:41Z oetiker $
+ * $Id: rrd_open.c 1735 2009-01-19 14:29:11Z oetiker $
  * $Log$
  * Revision 1.10  2004/05/26 22:11:12  oetiker
  * reduce compiler warnings. Many small fixes. -- Mike Slifcak <slif@bellsouth.net>
@@ -125,7 +125,7 @@ rrd_open(const char *file_name, FILE **in_file, rrd_t *rrd, int rdwr)
     MYFREAD(rrd->stat_head, stat_head_t,  1)
     /* lets see if the first read worked */
     if (ferror( *in_file ) || feof(*in_file)) {
-        rrd_set_error("reading the cookie off %s faild",file_name);
+        rrd_set_error("reading the cookie off %s failed",file_name);
         fclose(*in_file);
         return(-1);
     }        
