@@ -1,5 +1,5 @@
 /*****************************************************************************
- * RRDtool 1.2.28  Copyright by Tobi Oetiker, 1997-2008
+ * RRDtool 1.2.30  Copyright by Tobi Oetiker, 1997-2009
  *****************************************************************************
  * rrd_tool.c  Startup wrapper
  *****************************************************************************/
@@ -99,6 +99,8 @@ void PrintUsage(char *cmd)
 	   "\t\t[-Y|--alt-y-grid]\n"
 	   "\t\t[-y|--y-grid y-axis grid and label]\n"
 	   "\t\t[-v|--vertical-label string] [-w|--width pixels]\n"
+	   "\t\t[--right-axis scale:shift] [--right-axis-label label]\n"
+	   "\t\t[--right-axis-format format]\n"
 	   "\t\t[-h|--height pixels] [-o|--logarithmic]\n"
 	   "\t\t[-u|--upper-limit value] [-z|--lazy]\n"
 	   "\t\t[-l|--lower-limit value] [-r|--rigid]\n"
@@ -379,8 +381,7 @@ int main(int argc, char *argv[])
 		 == 0 ){
 
 #ifdef HAVE_CHROOT
-                chroot(argv[2]);
-                if (errno!=0){
+                if (chroot(argv[2]) != 0){
                    fprintf(stderr,"ERROR: can't change root to '%s' errno=%d\n",
                            argv[2],errno);
                     exit(errno);
@@ -397,8 +398,7 @@ int main(int argc, char *argv[])
              }
           }
           if (strcmp(firstdir,"")){
-             chdir(firstdir);
-             if (errno!=0){
+             if (chdir(firstdir)!=0){
                 fprintf(stderr,"ERROR: %s\n",rrd_strerror(errno));
                 exit(errno);
              }
@@ -496,8 +496,7 @@ int HandleInputLine(int argc, char **argv, FILE* out)
              return(1); 
           }
 #endif
-          chdir(argv[2]);
-          if (errno!=0){
+          if (chdir(argv[2]) != 0){
              printf("ERROR: %s\n",rrd_strerror(errno));
 	     return(1);
           }
@@ -529,8 +528,7 @@ int HandleInputLine(int argc, char **argv, FILE* out)
              return(1); 
           }
 #endif
-          mkdir(argv[2],0777);
-          if (errno!=0){
+          if (mkdir(argv[2],0777) != 0){
              printf("ERROR: %s\n",rrd_strerror(errno));
              return(1);
           }
